pub struct Executions { /* private fields */ }Expand description
Implements a client for the Cloud Run Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Executions::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_executions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Cloud Run Execution Control Plane API.
Configuration
To configure Executions use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://run.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Executions holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Executions in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Executions
impl Executions
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Executions.
let client = Executions::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Executions + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Executions + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_execution(&self) -> GetExecution
pub fn get_execution(&self) -> GetExecution
Gets information about an Execution.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions, name: &str
) -> Result<()> {
let response = client.get_execution()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_executions(&self) -> ListExecutions
pub fn list_executions(&self) -> ListExecutions
Lists Executions from a Job. Results are sorted by creation time, descending.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions, parent: &str
) -> Result<()> {
let mut list = client.list_executions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_execution(&self) -> DeleteExecution
pub fn delete_execution(&self) -> DeleteExecution
Deletes an Execution.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions, name: &str
) -> Result<()> {
let response = client.delete_execution()
.set_name(name)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_execution(&self) -> CancelExecution
pub fn cancel_execution(&self) -> CancelExecution
Cancels an Execution.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions
) -> Result<()> {
let response = client.cancel_execution()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Executions
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for Executions
impl Clone for Executions
Sourcefn clone(&self) -> Executions
fn clone(&self) -> Executions
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more