pub struct Jobs { /* private fields */ }Expand description
Implements a client for the Cloud Run Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Jobs::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_jobs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Cloud Run Job Control Plane API.
Configuration
To configure Jobs use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://run.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Jobs holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Jobs in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Jobs
impl Jobs
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Jobs.
let client = Jobs::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Jobs + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Jobs + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_job(&self) -> CreateJob
pub fn create_job(&self) -> CreateJob
Creates a Job.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::model::Job;
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs, parent: &str
) -> Result<()> {
let response = client.create_job()
.set_parent(parent)
.set_job_id("job_id_value")
.set_job(
Job::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_job(&self) -> GetJob
pub fn get_job(&self) -> GetJob
Gets information about a Job.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs, name: &str
) -> Result<()> {
let response = client.get_job()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_jobs(&self) -> ListJobs
pub fn list_jobs(&self) -> ListJobs
Lists Jobs. Results are sorted by creation time, descending.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs, parent: &str
) -> Result<()> {
let mut list = client.list_jobs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_job(&self) -> UpdateJob
pub fn update_job(&self) -> UpdateJob
Updates a Job.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::model::Job;
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs, name: &str
) -> Result<()> {
let response = client.update_job()
.set_job(
Job::new().set_name(name)/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_job(&self) -> DeleteJob
pub fn delete_job(&self) -> DeleteJob
Deletes a Job.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs, name: &str
) -> Result<()> {
let response = client.delete_job()
.set_name(name)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn run_job(&self) -> RunJob
pub fn run_job(&self) -> RunJob
Triggers creation of a new Execution of this Job.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
let response = client.run_job()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the IAM Access Control policy currently in effect for the given Job. This result does not include any inherited policies.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the IAM Access control policy for the specified Job. Overwrites any existing policy.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified Project.
There are no permissions required for making this API call.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Jobs
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}