pub struct Revisions { /* private fields */ }Expand description
Implements a client for the Cloud Run Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Revisions::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_revisions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Cloud Run Revision Control Plane API.
Configuration
To configure Revisions use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://run.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Revisions holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Revisions in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Revisions
impl Revisions
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Revisions.
let client = Revisions::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Revisions + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Revisions + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_revision(&self) -> GetRevision
pub fn get_revision(&self) -> GetRevision
Gets information about a Revision.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Revisions, name: &str
) -> Result<()> {
let response = client.get_revision()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_revisions(&self) -> ListRevisions
pub fn list_revisions(&self) -> ListRevisions
Lists Revisions from a given Service, or from a given location. Results are sorted by creation time, descending.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Revisions, parent: &str
) -> Result<()> {
let mut list = client.list_revisions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_revision(&self) -> DeleteRevision
pub fn delete_revision(&self) -> DeleteRevision
Deletes a Revision.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::Result;
async fn sample(
client: &Revisions, name: &str
) -> Result<()> {
let response = client.delete_revision()
.set_name(name)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Revisions
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Revisions
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Revisions
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Revisions
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}