pub struct Tasks { /* private fields */ }Expand description
Implements a client for the Cloud Run Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Tasks::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_tasks()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Cloud Run Task Control Plane API.
Configuration
To configure Tasks use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://run.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Tasks holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Tasks in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Tasks
impl Tasks
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Tasks.
let client = Tasks::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Tasks + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Tasks + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_task(&self) -> GetTask
pub fn get_task(&self) -> GetTask
Gets information about a Task.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Tasks, name: &str
) -> Result<()> {
let response = client.get_task()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_tasks(&self) -> ListTasks
pub fn list_tasks(&self) -> ListTasks
Lists Tasks from an Execution of a Job.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Tasks, parent: &str
) -> Result<()> {
let mut list = client.list_tasks()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &Tasks
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Tasks
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Tasks
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &Tasks
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}