pub struct WorkerPools { /* private fields */ }Expand description
Implements a client for the Cloud Run Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = WorkerPools::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_worker_pools()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Cloud Run WorkerPool Control Plane API.
Configuration
To configure WorkerPools use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://run.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
WorkerPools holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap WorkerPools in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl WorkerPools
impl WorkerPools
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for WorkerPools.
let client = WorkerPools::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: WorkerPools + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: WorkerPools + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_worker_pool(&self) -> CreateWorkerPool
pub fn create_worker_pool(&self) -> CreateWorkerPool
Creates a new WorkerPool in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::model::WorkerPool;
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools, parent: &str
) -> Result<()> {
let response = client.create_worker_pool()
.set_parent(parent)
.set_worker_pool(
WorkerPool::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_worker_pool(&self) -> GetWorkerPool
pub fn get_worker_pool(&self) -> GetWorkerPool
Gets information about a WorkerPool.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools, name: &str
) -> Result<()> {
let response = client.get_worker_pool()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_worker_pools(&self) -> ListWorkerPools
pub fn list_worker_pools(&self) -> ListWorkerPools
Lists WorkerPools. Results are sorted by creation time, descending.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools, parent: &str
) -> Result<()> {
let mut list = client.list_worker_pools()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_worker_pool(&self) -> UpdateWorkerPool
pub fn update_worker_pool(&self) -> UpdateWorkerPool
Updates a WorkerPool.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_run_v2::model::WorkerPool;
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools, name: &str
) -> Result<()> {
let response = client.update_worker_pool()
.set_worker_pool(
WorkerPool::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_worker_pool(&self) -> DeleteWorkerPool
pub fn delete_worker_pool(&self) -> DeleteWorkerPool
Deletes a WorkerPool.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools, name: &str
) -> Result<()> {
let response = client.delete_worker_pool()
.set_name(name)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the IAM Access Control policy currently in effect for the given Cloud Run WorkerPool. This result does not include any inherited policies.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the IAM Access control policy for the specified WorkerPool. Overwrites any existing policy.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified Project.
There are no permissions required for making this API call.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_run_v2::Result;
async fn sample(
client: &WorkerPools
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for WorkerPools
impl Clone for WorkerPools
Sourcefn clone(&self) -> WorkerPools
fn clone(&self) -> WorkerPools
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more