#[non_exhaustive]pub enum ExecutionReason {
Undefined,
JobStatusServicePollingError,
NonZeroExitCode,
Cancelled,
Cancelling,
Deleted,
DelayedStartPending,
UnknownValue(UnknownValue),
}Expand description
Reasons specific to Execution resource.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Undefined
Default value.
JobStatusServicePollingError
Internal system error getting execution status. System will retry.
NonZeroExitCode
A task reached its retry limit and the last attempt failed due to the user container exiting with a non-zero exit code.
Cancelled
The execution was cancelled by users.
Cancelling
The execution is in the process of being cancelled.
Deleted
The execution was deleted.
DelayedStartPending
A delayed execution is waiting for a start time.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ExecutionReason::value or ExecutionReason::name.
Implementations